function output_files = trigonometric_withfixedb_1stfit_and_export(input_csv, label)
    % TRIGONOMETRIC_FIT_AND_EXPORT - 对CSV文件中的数据前两列进行三角函数拟合并输出到CSV文件
    %
    % 输入:
    %   input_csv - 输入的CSV文件路径
    %   label - 数据组的标签（字符串形式，用于区分不同的数据组并生成输出文件名）
    %
    % 输出:
    %   output_files - 一个结构体，包含输出文件名的信息
    %                  .data_file - 包含原始数据、拟合数据和残差数据的CSV文件名
    %                  .params_file - 包含拟合参数的CSV文件名
 
    % 读取CSV文件
    data = readmatrix(input_csv);
    time = data(:, 1); % 第一列是时间
    values = data(:, 2:end); % 其他列是待拟合的数据
 
    % 初始化输出参数
    numCols = size(values, 2);
    all_params = zeros(numCols, 5); % 每列数据的拟合参数 [a, b, c, d, R^2]
    all_residuals = zeros(size(values)); % 每列数据的残差
    all_fitted_values = zeros(size(values)); % 每列数据的拟合值
 
    % 拟合三角函数模型 y = a*sin(b*x + c) + d
	T=60/2900;
	b=2*pi/T;
    model = @(params, x) params(1) * sin(b * x + params(2)) + params(3);
    % options = optimoptions('lsqcurvefit', 'Display', 'off'); % 关闭优化过程的显示
	% 设置优化选项
	options = optimoptions('lsqcurvefit', 'Display', 'off', 'Algorithm', 'levenberg-marquardt', 'MaxIter', 10000, 'TolFun', 1e-6);
    % 对第一列待拟合数据进行拟合
	i = 1;
    y = values(:, i);
	initial_params = [(max(y) - mean(y))/2, 0, mean(y)]; % 初始猜测参数
        
    % 执行拟合
    fitted_params = lsqcurvefit(model, initial_params, time, y, [], [], options);
        
    % 计算拟合后的y值
    y_fit = model(fitted_params, time);
        
    % 计算残差和R平方
    residuals = y - y_fit;
    SS_res = sum(residuals.^2);
    SS_tot = sum((y - mean(y)).^2);
    R_squared = 1 - (SS_res / SS_tot);
    
	fitted_params_srorage=[fitted_params(1), b, fitted_params(2:end)];
    % 存储拟合参数和残差
    all_params(i, :) = [fitted_params_srorage, R_squared];
    all_residuals(:, i) = residuals;
    all_fitted_values(:, i) = y_fit;
	% 第二列起，待拟合数据的参数c在上一列基础上减pi/3，其他参数不变
    for i = 2:numCols
        y = values(:, i);
        % 不执行拟合，而是在上一列基础上将c减pi/3，
        fitted_params(2) = fitted_params(2)-pi/3;
		if fitted_params(2)<-2*pi
			fitted_params(2) = fitted_params(2)+2*pi;
		end
        
        % 计算拟合后的y值
        y_fit = model(fitted_params, time);
        
        % 计算残差和R平方
        residuals = y - y_fit;
        SS_res = sum(residuals.^2);
        SS_tot = sum((y - mean(y)).^2);
        R_squared = 1 - (SS_res / SS_tot);
        
		fitted_params_srorage=[fitted_params(1), b, fitted_params(2:end)];
        % 存储拟合参数和残差
        all_params(i, :) = [fitted_params_srorage, R_squared];
        all_residuals(:, i) = residuals;
        all_fitted_values(:, i) = y_fit;
    end
 
    % 准备输出数据
    output_data = [time, values, all_fitted_values, all_residuals];
    header = {'FlowTime'};
    for i = 1:numCols
        header{end+1} = ['Col_', num2str(i), '_Original'];
	end
	for i = 1:numCols
        header{end+1} = ['Col_', num2str(i), '_Fitted'];
	end
	for i = 1:numCols
        header{end+1} = ['Col_', num2str(i), '_Residual'];
    end
    output_data_table = array2table(output_data, 'VariableNames', header);
 
    % 创建输出文件名
    data_filename = sprintf('1stoutput_data_withfixedb_%s.csv', label);
    params_filename = sprintf('1stfitted_params_withfixedb_%s.csv', label);
 
    % 写入原始数据、拟合数据和残差数据到CSV文件
    writetable(output_data_table, data_filename);
 
    % 准备拟合参数表头
    params_header = {'a', 'b', 'c', 'd', 'R^2'};
	output_param_table=array2table(all_params, 'VariableNames', params_header);
	%增加列以代表原始数据的列号
	NumCols={};
    for i = 1:numCols
	%NumCols{i}=[num2str(i)];
	NumCols{i}=[i];
    end
	output_param_table.NumCol=NumCols';
	%将原始数据的列号调至第1列
	output_param_table=output_param_table(:,{'NumCol','a', 'b', 'c', 'd', 'R^2'});
	writetable(output_param_table, params_filename);
    output_files = struct('data_file', data_filename, 'params_file', params_filename);
end